@@ -35,11 +35,19 @@ class Args:
             "-ph", "--patch_height", type=int, default=256,
             help="Height of patches.")
         parser.add_argument(
-            "-ow", "--overlap_width", type=int, default=1,
+            "-ow", "--overlap_width", type=int, default=0,
             help="Width of the overlapped area of patches.")
         parser.add_argument(
-            "-oh", "--overlap_height", type=int, default=1,
+            "-oh", "--overlap_height", type=int, default=0,
             help="Height of the overlapped area of patches")
+        parser.add_argument(
+            "-ox", "--offset_x", type=int, default=0,
+            help="The offset pixel along the x-axis."
+        )
+        parser.add_argument(
+            "-oy", "--offset_y", type=int, default=0,
+            help="The offset pixel along the y-axis."
+        )
         parser.add_argument(
             "-ss", "--start_sample", action="store_true",
             help="Generate samples at the start of the process.")
@@ -62,7 +70,11 @@ class Args:
         )
         parser.add_argument(
             "-co", "--coco_style", action="store_true",
-            help="Output as COCO style"
+            help="Output as COCO style."
+        )
+        parser.add_argument(
+            "-yo", "--yolo_style", action="store_true",
+            help="Output as YOLO style."
         )
         parser.add_argument(
             "-ra", "--ratio", default="8:1:1",
@@ -98,13 +110,17 @@ def main(command=None):
         overlap_height=args.overlap_height,
         on_foreground=args.on_foreground,
         on_annotation=args.on_annotation,
+        offset_x=args.offset_x,
+        offset_y=args.offset_y,
         start_sample=args.start_sample,
         finished_sample=args.finished_sample,
         extract_patches=args.extract_patches)
     patcher.get_patch_parallel(annotation.classes)
-    if args.voc_style or args.coco_style:
+    if args.voc_style or args.coco_style or args.yolo_style:
         converter = wp.converter(args.save_to/slide.filestem, args.save_to, args.ratio)
         if args.voc_style:
             converter.to_voc()
         if args.coco_style:
             converter.to_coco()
+        if args.yolo_style:
+            converter.to_yolo()
